from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from tbc_video_export.config.json import JsonConfig

DEFAULT_CONFIG: JsonConfig = {
    "profiles": [
        {
            "name": "ffv1_10bit",
            "type": None,
            "default": True,
            "video_profile": "ffv1",
            "video_format": "yuv422p10le",
            "audio_profile": "flac",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_10bit_pcm",
            "type": None,
            "default": None,
            "video_profile": "ffv1",
            "video_format": "yuv422p10le",
            "audio_profile": "pcm_24",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_8bit",
            "type": None,
            "default": None,
            "video_profile": "ffv1",
            "video_format": "yuv422p",
            "audio_profile": "flac",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_8bit_pcm",
            "type": None,
            "default": None,
            "video_profile": "ffv1",
            "video_format": "yuv422p",
            "audio_profile": "pcm_24",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_444",
            "type": None,
            "default": None,
            "video_profile": "ffv1",
            "video_format": "yuv444p",
            "audio_profile": "flac",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_444_pcm",
            "type": None,
            "default": None,
            "video_profile": "ffv1",
            "video_format": "yuv444p",
            "audio_profile": "pcm_24",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_luma",
            "type": "luma",
            "default": True,
            "video_profile": "ffv1",
            "video_format": "y8",
            "audio_profile": "flac",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_luma_pcm",
            "type": "luma",
            "default": None,
            "video_profile": "ffv1",
            "video_format": "y8",
            "audio_profile": "pcm_24",
            "filter_profiles": [],
        },
        {
            "name": "ffv1_luma_no_audio",
            "type": "luma",
            "default": None,
            "video_profile": "ffv1",
            "video_format": "y8",
            "audio_profile": None,
            "filter_profiles": [],
        },
        {
            "name": "prores_hq",
            "type": None,
            "default": None,
            "video_profile": "prores_422_hq",
            "video_format": "yuv422p10le",
            "audio_profile": "pcm_24",
            "filter_profiles": [],
        },
        {
            "name": "prores_4444xq",
            "type": None,
            "default": None,
            "video_profile": "prores_4444_xq",
            "video_format": "yuv444p10le",
            "audio_profile": "pcm_24",
            "filter_profiles": [],
        },
        {
            "name": "v210",
            "type": None,
            "default": None,
            "video_profile": "v210",
            "video_format": "yuv422p10le",
            "audio_profile": "pcm_24",
            "filter_profiles": [],
        },
        {
            "name": "v410",
            "type": None,
            "default": None,
            "video_profile": "v410",
            "video_format": "yuv422p10le",
            "audio_profile": "pcm_24",
            "filter_profiles": [],
        },
        {
            "name": "x264_web",
            "type": None,
            "default": None,
            "video_profile": "x264_web",
            "video_format": "yuv420p",
            "audio_profile": "aac_320",
            "filter_profiles": ["bwdif", "colorlevels32"],
        },
        {
            "name": "x264_lossless",
            "type": None,
            "default": None,
            "video_profile": "x264_lossless",
            "video_format": "yuv422p10le",
            "audio_profile": "flac",
            "filter_profiles": [],
        },
        {
            "name": "x264_lossless_8bit",
            "type": None,
            "default": None,
            "video_profile": "x264_lossless",
            "video_format": "yuv422p",
            "audio_profile": "flac",
            "filter_profiles": [],
        },
        {
            "name": "x265_web",
            "type": None,
            "default": None,
            "video_profile": "x265_web",
            "video_format": "yuv420p",
            "audio_profile": "aac_320",
            "filter_profiles": ["bwdif", "colorlevels32"],
        },
        {
            "name": "x265_lossless",
            "type": None,
            "default": None,
            "video_profile": "x265_lossless",
            "video_format": "yuv422p10le",
            "audio_profile": "flac",
            "filter_profiles": [],
        },
        {
            "name": "x265_lossless_8bit",
            "type": None,
            "default": None,
            "video_profile": "x265_lossless",
            "video_format": "yuv422p",
            "audio_profile": "flac",
            "filter_profiles": [],
        },
    ],
    "video_profiles": [
        {
            "name": "ffv1",
            "description": "FFV1",
            "codec": "ffv1",
            "container": "mkv",
            "opts": [
                "-coder",
                1,
                "-level",
                3,
                "-context",
                1,
                "-slices",
                24,
                "-slicecrc",
                1,
                "-g",
                1,
            ],
        },
        {
            "name": "prores_422_hq",
            "description": "ProRes 422 HQ",
            "codec": "prores",
            "container": "mov",
            "opts": [
                "-profile:v",
                3,
                "-vendor",
                "apl0",
                "-bits_per_mb",
                8000,
                "-quant_mat",
                "hq",
                "-mbs_per_slice",
                8,
            ],
        },
        {
            "name": "prores_4444_xq",
            "description": "ProRes 4444 XQ",
            "codec": "prores",
            "container": "mov",
            "opts": [
                "-profile:v",
                5,
                "-vendor",
                "apl0",
                "-bits_per_mb",
                8000,
                "-quant_mat",
                "hq",
                "-mbs_per_slice",
                8,
            ],
        },
        {
            "name": "v210",
            "description": "V210",
            "codec": "v210",
            "container": "mov",
            "opts": None,
        },
        {
            "name": "v410",
            "description": "V410",
            "codec": "v410",
            "container": "mov",
            "opts": None,
        },
        {
            "name": "x264_web",
            "description": "x264 (Web)",
            "codec": "libx264",
            "container": "mov",
            "opts": [
                "-crf",
                18,
                "-preset",
                "slow",
                "-maxrate",
                "8M",
                "-bufsize",
                "16M",
                "-movflags",
                "+faststart",
                "-x264opts",
                "interlaced=0",
            ],
        },
        {
            "name": "x264_lossless",
            "description": "x264 (Lossless)",
            "codec": "libx264",
            "container": "mov",
            "opts": ["-qp", 0, "-preset", "veryslow"],
        },
        {
            "name": "x265_web",
            "description": "x265 (Web)",
            "codec": "libx265",
            "container": "mov",
            "opts": [
                "-crf",
                20,
                "-preset",
                "slow",
                "-maxrate",
                "8M",
                "-bufsize",
                "16M",
                "-movflags",
                "+faststart",
                "-x265-params",
                "interlace=false",
            ],
        },
        {
            "name": "x265_lossless",
            "description": "x265 (Lossless)",
            "codec": "libx265",
            "container": "mov",
            "opts": [
                "-preset",
                "veryslow",
                "-movflags",
                "+faststart",
                "-x265-params",
                "lossless=1",
            ],
        },
    ],
    "audio_profiles": [
        {
            "name": "flac",
            "description": "FLAC",
            "codec": "flac",
            "opts": ["-compression_level", 12],
        },
        {"name": "pcm_24", "description": "PCM", "codec": "pcm_s24le", "opts": None},
        {
            "name": "aac_320",
            "description": "AAC",
            "codec": "aac",
            "opts": ["-ar", 48000, "-b:a", "320K"],
        },
    ],
    "filter_profiles": [
        {
            "name": "bwdif",
            "description": "BWDIF",
            "video_filter": "bwdif",
            "other_filter": None,
        },
        {
            "name": "colorlevels32",
            "description": "Colorlevels (32)",
            "video_filter": "colorlevels=rimin=32/255:gimin=32/255:bimin=32/255",
            "other_filter": None,
        },
        {
            "name": "map_l_to_lr",
            "description": "Map L to L+R",
            "video_filter": None,
            "other_filter": "[2:a]pan=stereo|FL=FL|FR=FL",
        },
        {
            "name": "map_r_to_lr",
            "description": "Map R to L+R",
            "video_filter": None,
            "other_filter": "[2:a]pan=stereo|FR=FR|FL=FR",
        },
    ],
}
